push method
Push an item to the end of the PersistentQueue after buffer clears.
p.s. item must be json encodable, as json.encode() is called over it
Implementation
Future<void> push(dynamic item) => _defer(() => _push(item));
Push an item to the end of the PersistentQueue after buffer clears.
p.s. item must be json encodable, as json.encode() is called over it
Future<void> push(dynamic item) => _defer(() => _push(item));